# MyDBF2MySQL - Software for transferring DBF into MySQL.
# Copyright (C) 2008-2010 Polyakov Andrey
#
# http://sourceforge.net/projects/mydbf2mysql/
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, version 2
# of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

import logging, sys


class levelFilter(logging.Filter):
    def __init__(self, passlevel, reject):
        self.passlevel = passlevel
        self.reject = reject

    def filter(self, record):
        if self.reject:
            return (record.levelno != self.passlevel)
        else:
            return (record.levelno == self.passlevel)

def createLogger(
                 name,
                 format,
                 level,
                 filename=False
                 ):
    """
    Create logger which logs to stdout and stderr or to file.
    @ param name Logger name.
    @ param format Logger formatting string.
    @ param level Verbose level.
    @ param filename If specified, this logger will log to file.
    @return: Logger.
    """
    logger = logging.getLogger(name)
    if len(logger.handlers) < 1:
        logger.setLevel(level)
        formatter = logging.Formatter(format)
        if filename:
            handler1 = logging.FileHandler(filename)
        else:
            """ This pass info level to stdout, other levels to stderr."""
            filter = levelFilter(logging.INFO, False)
            reversed_filter = levelFilter(logging.INFO, True)
            handler1 = logging.StreamHandler(sys.stdout)
            handler1.addFilter(filter)
            handler2 = logging.StreamHandler(sys.stderr)
            handler2.addFilter(reversed_filter)
            handler2.setLevel(logging.DEBUG)
            handler2.setFormatter(formatter)
            logger.addHandler(handler2)
        handler1.setLevel(logging.DEBUG)
        handler1.setFormatter(formatter)
        logger.addHandler(handler1)
    return logger

