# MyDBF2MySQL - Software for transferring DBF into MySQL.
# Copyright (C) 2008-2010 Polyakov Andrey
#
# http://sourceforge.net/projects/mydbf2mysql/
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, version 2
# of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

from sys import stderr
from ydbf import YDbfReader
from ydbf import lib as libydbf
from MyDBF2MySQL.codes import *


def printFileSummary(dbfFile, OPT_STRICT):
    """Print detailed information about DBF file."""
    try:
        dbfr = YDbfReader(fh=file(dbfFile, 'rb'), strict=OPT_STRICT)
    except IOError, (errno, strerror):
        stderr.write("mydbf2mysql: error: I/O failure: %s, %s\n" % \
                        (errno, strerror))
        exit(EXIT_IO_FAILURE)
    except libydbf.DbfError, (errno, strerror):
        stderr.write("mydbf2mysql: error: Ydbf: %s, %s\n" % \
                        (errno, strerror))
        exit(EXIT_DBF_FAILURE)
    except:
        stderr.write("mydbf2mysql: error: Failed to open DBF file, unexpected error occurred.\n")
        exit(EXIT_FAILURE)
    print "Number of records: %s" % dbfr.numrec
    print "Size of each record (in bytes): %s" % dbfr.recsize
    print "Length of header is: %s" % dbfr.lenheader
    print "Structure format is: %s" % libydbf.SIGNATURES[dbfr.sig]
    print "File encoding is: %s" % libydbf.ENCODINGS[dbfr.raw_lang][1]
    print "Name".center(16, " "), " ", "Type".center(2, " "), " ", \
          "Length".center(6, " "), " ", "Dec"
    for one_field in dbfr.fields:
        print one_field[0].center(16, " "), " ", one_field[1].center(2, " "), " ", \
        str(one_field[2]).center(6, " "), " ", str(one_field[3]).center(6, " ")
    return

def printSupportedEncodings():
    """Output some constants."""
    print "Supported encodings:"
    for encodingIndex in libydbf.ENCODINGS:
        thisPair = libydbf.ENCODINGS[encodingIndex]
        print " " * (12 - len(thisPair[0])), thisPair[0], "   ", thisPair[1]
    print "Supported DBF formats:"
    for index in libydbf.SUPPORTED_SIGNATURES:
        print " " * (12 - len(libydbf.SIGNATURES[index])), libydbf.SIGNATURES[index]
    print "Supported data filters: int, float, ebz2, dbz2"
    return

